# Skip

Skip is a Python-based data-forward static site generator inspired by [Eleventy](https://11ty.dev)

## Why should I use Skip?

- You like Python and the Jinja2 templating engine
- You want a simple static site generator that makes no assumptions about how your project should be structured
- You want to use data files, including dynamically computed data (like reading from a database or API)

## Quickstart

``` bash
pip install skip-ssg
echo '# Hello World' > index.md
skip
```

To see more, check out the [documentation](http://skip.harryeldridge.com)
